diff mbox series

[01/10] ASoC: max98088: Use modern ASoC DAI format terminology

Message ID 20220222234026.712070-1-broonie@kernel.org
State Accepted
Commit 14688a14dac34aac979c1e5386278f914a73164f
Headers show
Series [01/10] ASoC: max98088: Use modern ASoC DAI format terminology | expand

Commit Message

Mark Brown Feb. 22, 2022, 11:40 p.m. UTC
As part of moving to remove the old style defines for the bus clocks update
the max98088 driver to use more modern terminology for clocking.

Signed-off-by: Mark Brown <broonie@kernel.org>
---
 sound/soc/codecs/max98088.c | 24 ++++++++++--------------
 1 file changed, 10 insertions(+), 14 deletions(-)

Comments

Mark Brown Feb. 28, 2022, 7:15 p.m. UTC | #1
On Tue, 22 Feb 2022 23:40:17 +0000, Mark Brown wrote:
> As part of moving to remove the old style defines for the bus clocks update
> the max98088 driver to use more modern terminology for clocking.
> 
> 

Applied to

   https://git.kernel.org/pub/scm/linux/kernel/git/broonie/sound.git for-next

Thanks!

[01/10] ASoC: max98088: Use modern ASoC DAI format terminology
        commit: 14688a14dac34aac979c1e5386278f914a73164f
[02/10] ASoC: max98095: Use modern ASoC DAI format terminology
        commit: 2232314b7dbcf19a897e72e00d154b19669181e5
[03/10] ASoC: max98371: Use modern ASoC DAI format terminology
        commit: 012df28f5e143747c82d2b03428f607445fda893
[04/10] ASoC: max98390: Use modern ASoC DAI format terminology
        commit: c536d745adbc83abb782077a212a8cbdd7300b54
[05/10] ASoC: max9850: Use modern ASoC DAI format terminology
        commit: 9dcef176c4d68abc9765b420c38cca6aa85600da
[06/10] ASoC: max9860: Use modern ASoC DAI format terminology
        commit: d14c87d8ef0da4500ee8a0a3273972f4bb549412
[07/10] ASoC: max9867: Use modern ASoC DAI format terminology
        commit: 2594d0aaedade65b4f746cda0f304400eb1a9870
[08/10] ASoC: max98925: Use modern ASoC DAI format terminology
        commit: 02dd4e6ba25ca343adf228c34955ca0036a6ade3
[09/10] ASoC: max98926: Use modern ASoC DAI format terminology
        commit: 502e1c8d07222561b046a1da7b8207696f575288
[10/10] ASoC: max98927: Use modern ASoC DAI format terminology
        commit: 677c90bac3f198434f0256338cefc77e4663bcca

All being well this means that it will be integrated into the linux-next
tree (usually sometime in the next 24 hours) and sent to Linus during
the next merge window (or sooner if it is a bug fix), however if
problems are discovered then the patch may be dropped or reverted.

You may get further e-mails resulting from automated or manual testing
and review of the tree, please engage with people reporting problems and
send followup patches addressing any issues that are reported if needed.

If any updates are required or you are submitting further changes they
should be sent as incremental updates against current git, existing
patches will not be replaced.

Please add any relevant lists and maintainers to the CCs when replying
to this mail.

Thanks,
Mark
diff mbox series

Patch

diff --git a/sound/soc/codecs/max98088.c b/sound/soc/codecs/max98088.c
index f8e49e45ce33..429717d4ac5a 100644
--- a/sound/soc/codecs/max98088.c
+++ b/sound/soc/codecs/max98088.c
@@ -1156,20 +1156,18 @@  static int max98088_dai1_set_fmt(struct snd_soc_dai *codec_dai,
        if (fmt != cdata->fmt) {
                cdata->fmt = fmt;
 
-               switch (fmt & SND_SOC_DAIFMT_MASTER_MASK) {
-               case SND_SOC_DAIFMT_CBS_CFS:
-                       /* Slave mode PLL */
+               switch (fmt & SND_SOC_DAIFMT_CLOCK_PROVIDER_MASK) {
+               case SND_SOC_DAIFMT_CBC_CFC:
+                       /* Consumer mode PLL */
                        snd_soc_component_write(component, M98088_REG_12_DAI1_CLKCFG_HI,
                                0x80);
                        snd_soc_component_write(component, M98088_REG_13_DAI1_CLKCFG_LO,
                                0x00);
                        break;
-               case SND_SOC_DAIFMT_CBM_CFM:
-                       /* Set to master mode */
+               case SND_SOC_DAIFMT_CBP_CFP:
+                       /* Set to provider mode */
                        reg14val |= M98088_DAI_MAS;
                        break;
-               case SND_SOC_DAIFMT_CBS_CFM:
-               case SND_SOC_DAIFMT_CBM_CFS:
                default:
                        dev_err(component->dev, "Clock mode unsupported");
                        return -EINVAL;
@@ -1227,20 +1225,18 @@  static int max98088_dai2_set_fmt(struct snd_soc_dai *codec_dai,
        if (fmt != cdata->fmt) {
                cdata->fmt = fmt;
 
-               switch (fmt & SND_SOC_DAIFMT_MASTER_MASK) {
-               case SND_SOC_DAIFMT_CBS_CFS:
-                       /* Slave mode PLL */
+               switch (fmt & SND_SOC_DAIFMT_CLOCK_PROVIDER_MASK) {
+               case SND_SOC_DAIFMT_CBC_CFC:
+                       /* Consumer mode PLL */
                        snd_soc_component_write(component, M98088_REG_1A_DAI2_CLKCFG_HI,
                                0x80);
                        snd_soc_component_write(component, M98088_REG_1B_DAI2_CLKCFG_LO,
                                0x00);
                        break;
-               case SND_SOC_DAIFMT_CBM_CFM:
-                       /* Set to master mode */
+               case SND_SOC_DAIFMT_CBP_CFP:
+                       /* Set to provider mode */
                        reg1Cval |= M98088_DAI_MAS;
                        break;
-               case SND_SOC_DAIFMT_CBS_CFM:
-               case SND_SOC_DAIFMT_CBM_CFS:
                default:
                        dev_err(component->dev, "Clock mode unsupported");
                        return -EINVAL;